summaryrefslogtreecommitdiffstats
path: root/src/core/qchangearbiter.cpp
diff options
context:
space:
mode:
authorPaul Lemire <paul.lemire.ecortex.kdab.com>2014-10-29 09:32:18 +0100
committerSean Harmer <sean.harmer@kdab.com>2014-11-02 12:43:28 +0100
commit8bd7ea0ec2f67679d046d35af5785d99b31620a3 (patch)
treece8b1290edc55a27f867cc6a044d69596e113b1f /src/core/qchangearbiter.cpp
parent22aae0f06bf90ece7435e9dfa4059f1615046eff (diff)
QNodeUuid: typedef for QUuid
Should allow to easily replace QUuid by a custom quint64 based struct Change-Id: Ib4ba57efd2e070317aa3417b37ce091f2b4779a0 Reviewed-by: Sean Harmer <sean.harmer@kdab.com>
Diffstat (limited to 'src/core/qchangearbiter.cpp')
-rw-r--r--src/core/qchangearbiter.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/core/qchangearbiter.cpp b/src/core/qchangearbiter.cpp
index 826cedc07..9393afe52 100644
--- a/src/core/qchangearbiter.cpp
+++ b/src/core/qchangearbiter.cpp
@@ -68,11 +68,11 @@ namespace Qt3D {
* the QPostman to deliver the messages to the frontend QNode.
*
* QNode observables are registered automatically. However QObservableInterface have to be registered manually
* by providing the QUuid of the frontend QNode that observables is mapped to.
*
* Observers can be registered to receive messages from a QObservableInterface/QNode observable by providing a QNode QUuid.
* When a notification from a QObservableInterface is received, it is then sent to all observers observing the
* QNode QUuid as well as the QPostman to update the frontend QNode.
*/
@@ -131,7 +131,7 @@ void QChangeArbiter::distributeQueueChanges(ChangeQueue *changeQueue)
case QSceneChange::Observable: {
QObservableInterface *subject = change->subject().m_observable;
- QUuid nodeId = m_scene->nodeIdFromObservable(subject);
+ QNodeUuid nodeId = m_scene->nodeIdFromObservable(subject);
if (m_nodeObservations.contains(nodeId)) {
QObserverList &observers = m_nodeObservations[nodeId];
Q_FOREACH (const QObserverPair&observer, observers) {
@@ -210,7 +210,7 @@ QSceneInterface *QChangeArbiter::scene() const
}
void QChangeArbiter::registerObserver(QObserverInterface *observer,
- const QUuid &nodeId,
+ const QNodeUuid &nodeId,
ChangeFlags changeFlags)
{
QMutexLocker locker(&m_mutex);
@@ -225,7 +225,7 @@ void QChangeArbiter::registerSceneObserver(QSceneObserverInterface *observer)
m_sceneObservers << observer;
}
-void QChangeArbiter::unregisterObserver(QObserverInterface *observer, const QUuid &nodeId)
+void QChangeArbiter::unregisterObserver(QObserverInterface *observer, const QNodeUuid &nodeId)
{
QMutexLocker locker(&m_mutex);
if (m_nodeObservations.contains(nodeId)) {
@@ -68,11 +68,11 @@ namespace Qt3D {
*
* QNode observables are registered automatically. However QObservableInterface have to be registered manually
- * by providing the QUuid of the frontend QNode that observables is mapped to.
+ * by providing the NodeUuid of the frontend QNode that observables is mapped to.
*
@@ -68,11 +68,11 @@ namespace Qt3D {
*
- * Observers can be registered to receive messages from a QObservableInterface/QNode observable by providing a QNode QUuid.
+ * Observers can be registered to receive messages from a QObservableInterface/QNode observable by providing a QNode NodeUuid.
* When a notification from a QObservableInterface is received, it is then sent to all observers observing the
@@ -68,11 +68,11 @@ namespace Qt3D {
* When a notification from a QObservableInterface is received, it is then sent to all observers observing the
- * QNode QUuid as well as the QPostman to update the frontend QNode.
+ * QNode NodeUuid as well as the QPostman to update the frontend QNode.
*/